
.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api


.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/jposada202020/CircuitPython_isl29125/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
